'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.writeSync = writeSync;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _logUpdate = require('log-update');

var _logUpdate2 = _interopRequireDefault(_logUpdate);

var _onetime = require('onetime');

var _onetime2 = _interopRequireDefault(_onetime);

var _exitHook = require('exit-hook');

var _exitHook2 = _interopRequireDefault(_exitHook);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @copyright 2016-present, Sitegen team
 */

var NEWLINE = '\n';

var installExitHook = (0, _onetime2.default)(function () {
  return (0, _exitHook2.default)(function () {
    return OutputRenderer.done();
  });
});

var OutputRenderer = {

  stdout: [],
  stderr: [],

  _stdoutWrite: process.stdout.write,
  _stderrWrite: process.stderr.write,
  _consoleLog: console.log, // eslint-disable-line no-console
  _consoleWarning: console.warning, // eslint-disable-line no-console
  _consoleError: console.error, // eslint-disable-line no-console
  _consoleDebug: console.debug, // eslint-disable-line no-console

  get hasBuffer() {
    return this.stdout.length || this.stderr.length;
  },

  manage: function manage() {
    var _this = this;

    process.stdout.write = function (msg) {
      return _this.stdout.push(msg);
    };
    process.stderr.write = function (msg) {
      return _this.stderr.push(msg);
    };
    console.log = function (msg) {
      return _this.stdout.push(msg + NEWLINE);
    }; // eslint-disable-line no-console
    console.warning = function (msg) {
      return _this.stderr.push(msg + NEWLINE);
    }; // eslint-disable-line no-console
    console.error = function (msg) {
      return _this.stderr.push(msg + NEWLINE);
    }; // eslint-disable-line no-console
    console.debug = function (msg) {
      return _this.stderr.push(msg + NEWLINE);
    }; // eslint-disable-line no-console
    installExitHook();
  },
  release: function release() {
    process.stdout.write = this._stdoutWrite;
    process.stderr.write = this._stderrWrite;
    console.log = this._consoleLog; // eslint-disable-line no-console
    console.warning = this._consoleWarning; // eslint-disable-line no-console
    console.error = this._consoleError; // eslint-disable-line no-console
    console.debug = this._consoleDebug; // eslint-disable-line no-console
  },
  flush: function flush() {
    if (this.hasBuffer) {
      updateScreen.clear();
    }
    this._flush();
  },
  _flush: function _flush() {
    if (this.stdout.length > 0) {
      writeSync(1, this.stdout.join(''), true);
      this.stdout = [];
    }
    if (this.stderr.length > 0) {
      writeSync(2, this.stderr.join(''), true);
      this.stderr = [];
    }
  },
  render: function render(content) {
    updateScreen(content);
  },
  done: function done() {
    this.flush();
    updateScreen.clear();
    updateScreen.done();
    this.release();
  }
};

function writeSync(fd, msg, flush) {
  _fs2.default.writeSync(fd, msg);
  if (flush) {
    _fs2.default.fsyncSync(fd);
  }
}

var updateScreen = _logUpdate2.default.create({
  write: function write(msg) {
    writeSync(1, msg, false);
  }
});

exports.default = OutputRenderer;
