'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _padStart = require('lodash/padStart');

var _padStart2 = _interopRequireDefault(_padStart);

var _padEnd = require('lodash/padEnd');

var _padEnd2 = _interopRequireDefault(_padEnd);

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

require('colour');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Terminal progress bar, based on code found in reactpack.
 *
 * @copyright 2016, Ola Holmström
 * @copyright 2016-present, Sitegen team
 * 
 */

var THEMES = {
  unicode: {
    complete: '▓',
    incomplete: '░'
  },
  ascii: {
    complete: '#',
    incomplete: '-'
  },
  cp437: {
    complete: '█',
    incomplete: '░'
  }
};

var ProgressBar = function () {
  function ProgressBar(name) {
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
    (0, _classCallCheck3.default)(this, ProgressBar);

    this.name = name;
    this.message = '';
    this.spun = 0;
    this.progress = 0;
    this.theme = options.theme || THEMES.unicode;
    this._largestMsgWidth = 0;
  }

  (0, _createClass3.default)(ProgressBar, [{
    key: '_columns',
    value: function _columns() {
      // $FlowIssue: add to defs!
      return process.stdout.columns - 1;
    }
  }, {
    key: '_renderMessage',
    value: function _renderMessage() {
      return _util2.default.format('%s', (0, _padEnd2.default)(this.message, this._largestMsgWidth));
    }
  }, {
    key: '_renderBar',
    value: function _renderBar() {
      var _this = this;

      var percentage = this.progress;

      var getProgressWidth = function getProgressWidth() {
        return _this._columns() - _this._renderMessage().length;
      };

      var getComplete = function getComplete(percentage) {
        return (0, _padStart2.default)('', Math.floor(percentage * getProgressWidth()), _this.theme.complete);
      };

      var getIncomplete = function getIncomplete(percentage) {
        var width = getProgressWidth() - Math.floor(percentage * getProgressWidth());
        return (0, _padEnd2.default)('', width, _this.theme.incomplete);
      };

      var complete = getComplete(percentage).blue;
      var incomplete = getIncomplete(percentage);

      return complete + incomplete;
    }
  }, {
    key: 'update',
    value: function update(message, percentage) {
      message = this.name + ': ' + message;
      this.message = message.trim() === '' ? this.message : message;
      this._largestMsgWidth = Math.max(message.length, this._largestMsgWidth);
      this.progress = percentage || this.progress;
    }
  }, {
    key: 'render',
    value: function render() {
      var bar = this._renderBar(this.progress);
      var message = this._renderMessage();

      return _util2.default.format('%s %s', message, bar);
    }
  }]);
  return ProgressBar;
}();

exports.default = ProgressBar;
