#!/usr/bin/env node
'use strict';

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _webpackDevMiddleware = require('webpack-dev-middleware');

var _webpackDevMiddleware2 = _interopRequireDefault(_webpackDevMiddleware);

var _webpackHotMiddleware = require('webpack-hot-middleware');

var _webpackHotMiddleware2 = _interopRequireDefault(_webpackHotMiddleware);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _server = require('react-dom/server');

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _utils = require('./utils');

var _compiler = require('../compiler');

var _OutputRenderer = require('./OutputRenderer');

var _OutputRenderer2 = _interopRequireDefault(_OutputRenderer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @copyright 2016-present, Sitegen team
 */

var debug = (0, _debug2.default)('sitegen:cmd:serve');

var args = (0, _utils.parse)();

var _args$args = (0, _slicedToArray3.default)(args.args, 1);

var entry = _args$args[0];


var frames = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'];
var i = 0;

_OutputRenderer2.default.manage();

function setFlushInterval() {
  return setTimeout(function () {
    onProgress(1);
  }, 100);
}

var interval = null;
var start = null;
var finish = null;

function onProgress(percent, _msg) {
  _OutputRenderer2.default.flush();
  if (percent == 0) {
    start = Date.now();
    finish = null;
    clearTimeout(interval);
  } else if (percent == 1) {
    if (finish === null) {
      finish = Date.now();
    }
    _OutputRenderer2.default.render([_chalk2.default.white('Serving at http://localhost:3000'), 'Build: ' + _chalk2.default.green('done') + ' (' + (finish - start) / 1000 + 's)'].join('\n'));
    interval = setFlushInterval();
  } else {
    var frame = frames[i = ++i % frames.length];
    _OutputRenderer2.default.render([_chalk2.default.white('Serving at http://localhost:3000'), 'Build: ' + _chalk2.default.blue(frame)].join('\n'));
  }
}

var compiler = (0, _compiler.createCompiler)({
  entry: entry,
  env: 'development',
  publicPath: args.publicPath,
  progress: onProgress
});

var compileDevMiddleware = (0, _webpackDevMiddleware2.default)(compiler, {
  noInfo: false,
  quiet: true,
  stats: {
    chunks: false,
    modules: false
  }
});

var compileHotMiddleware = (0, _webpackHotMiddleware2.default)(compiler, {
  log: function log() {}
});

function render(req, res, next) {
  compiler.promiseBundle.then(function (mod) {
    return res.send((0, _server.renderToStaticMarkup)(_react2.default.createElement(mod.Site, { bundle: { js: '/bundle.js' } })));
  }, function (err) {
    return next(err);
  });
}

(0, _express2.default)().use(compileDevMiddleware).use(compileHotMiddleware).use(render).listen(3000, function () {
  return debug('started listening on port 3000');
});
